@@ -5,7 +5,7 @@ use Test::Builder::Module;
 use Test::Name::FromLine;
 use Text::MatchedPosition;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 our @ISA = qw/Test::Builder::Module/;
 
@@ -20,6 +20,10 @@ sub import {
     $pkg->_import_option_no_warnings(\%args);
     $pkg->_import_option_binary(\%args);
 
+    if (scalar(keys %args) > 0) {
+        die "Wrong option: " . join(", ", keys %args);
+    }
+
     if ($] < 5.014000) {
         require IO::Handle;
         IO::Handle->import;
@@ -60,9 +64,15 @@ sub new {
     my $class = shift;
     my %args  = @_;
 
-    bless {
+    my $self = bless {
         no_x => delete $args{'no_x'},
     }, $class;
+
+    if ($args{plan}) {
+        $self->plan(%{$args{plan}});
+    }
+
+    $self;
 }
 
 sub _tb { __PACKAGE__->builder }
@@ -80,6 +90,43 @@ sub _reset {
 sub pass { shift; _tb->ok(PASS, @_) }
 sub fail { shift; _tb->ok(FAIL, @_) }
 
+sub plan {
+    my $self = shift;
+
+    return _tb->plan(@_);
+}
+
+sub _carp {
+    my($file, $line) = ( caller(1) )[ 1, 2 ];
+    return warn @_, " at $file line $line\n";
+}
+
+sub skip {
+    my($self, $why, $how_many) = @_;
+
+    # If the plan is set, and is static, then skip needs a count. If the plan
+    # is 'no_plan' we are fine. As well if plan is undefined then we are
+    # waiting for done_testing.
+    unless (defined $how_many) {
+        my $plan = _tb->has_plan;
+        _carp "skip() needs to know \$how_many tests are in the block"
+            if $plan && $plan =~ m/^\d+$/;
+        $how_many = 1;
+    }
+
+    if(defined $how_many and $how_many =~ /\D/) {
+        _carp "skip() was passed a non-numeric number of tests.  Did you get the arguments backwards?";
+        $how_many = 1;
+    }
+
+    for(1 .. $how_many) {
+        _tb->skip($why);
+    }
+
+    no warnings 'exiting';
+    last SKIP;
+}
+
 sub BAIL_OUT {
     _tb->BAIL_OUT(scalar @_ == 1 ? $_[0] : $_[1]);
 }
@@ -571,6 +618,35 @@ The constructor.
 
 If you set C<no_x> option the ture value, then the C<x> method doesn't show any message.
 
+=item plan
+
+If you set C<plan> option with hash, then the C<plan> method, it's same as Test::More's one, it will be called in constructor.
+
+    my $arr = Test::Arrow->new(
+        plan => {
+            tests => 2,
+        }
+    );
+
+    $arr->ok(1);
+    $arr->is(1, 1);
+
+If you want to skip all tests,
+
+    my $arr = Test::Arrow->new(
+        plan => {
+            skip_all => 'Reason',
+        }
+    );
+
+Test::More has the import option for test plan, but Test::Arrow doesn't. Below code doesn't work as your intent.
+
+    use Test::Arrow plan => 12;
+
+It should be in constructor option or should be called as straightforward method/function.
+
+    $arr->plan(skip_all => 'Reason');
+
 =back
 
 =head2 SETTERS
@@ -735,6 +811,20 @@ C<warning> is an alias of C<warnings>.
 
 Terminates tests.
 
+=head2 CONDITIONAL TESTS
+
+=head3 skip
+
+In order to skip tests like below.
+
+    SKIP: {
+        $arr->skip($why, $how_many) if $condition;
+
+        ...normal testing code goes here...
+    }
+
+Test::Arrow doesn't have C<todo_skip>.
+
 =head2 UTILITIES
 
 You can call below utilities methods even without an instance.
@@ -811,7 +901,7 @@ Alias of C<done_testing>
 
 =begin html
 
-<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.13-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1583027570"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1583027570&branch=master"/></a>
+<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.14-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1583338249"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1583338249&branch=master"/></a>
 
 =end html
 
